==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/ConnectionSettingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for a Connection Setting Item
 * @property clientId Client Id associated with the Connection Setting.
 * @property clientSecret Client Secret associated with the Connection Setting
 * @property id Id of the Connection Setting.
 * @property name Name of the Connection Setting.
 * @property parameters Service Provider Parameters associated with the Connection Setting
 * @property provisioningState Provisioning state of the resource
 * @property scopes Scopes associated with the Connection Setting
 * @property serviceProviderDisplayName Service Provider Display Name associated with the Connection Setting
 * @property serviceProviderId Service Provider Id associated with the Connection Setting
 */
public data class ConnectionSettingPropertiesArgs(
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val parameters: Output<List<ConnectionSettingParameterArgs>>? = null,
    public val provisioningState: Output<String>? = null,
    public val scopes: Output<String>? = null,
    public val serviceProviderDisplayName: Output<String>? = null,
    public val serviceProviderId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .scopes(scopes?.applyValue({ args0 -> args0 }))
            .serviceProviderDisplayName(serviceProviderDisplayName?.applyValue({ args0 -> args0 }))
            .serviceProviderId(serviceProviderId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionSettingPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionSettingPropertiesArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecret: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parameters: Output<List<ConnectionSettingParameterArgs>>? = null

    private var provisioningState: Output<String>? = null

    private var scopes: Output<String>? = null

    private var serviceProviderDisplayName: Output<String>? = null

    private var serviceProviderId: Output<String>? = null

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("jmhfejiugsngstfv")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("edwykfavdmdchbep")
    public suspend fun clientSecret(`value`: Output<String>) {
        this.clientSecret = value
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("pqlmvdenacosewyu")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("oypfwhnjpbreuhjf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("oelinfdnlosbasgw")
    public suspend fun parameters(`value`: Output<List<ConnectionSettingParameterArgs>>) {
        this.parameters = value
    }

    @JvmName("jwbssaoimfjoshky")
    public suspend fun parameters(vararg values: Output<ConnectionSettingParameterArgs>) {
        this.parameters = Output.all(values.asList())
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("avqobyvvybyofxhm")
    public suspend fun parameters(values: List<Output<ConnectionSettingParameterArgs>>) {
        this.parameters = Output.all(values)
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("vmtyxhchmefuurvr")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("gmiulrfpkolpxldd")
    public suspend fun scopes(`value`: Output<String>) {
        this.scopes = value
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("nmqapobeaksxvkcj")
    public suspend fun serviceProviderDisplayName(`value`: Output<String>) {
        this.serviceProviderDisplayName = value
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("pflqqxejhneykrgg")
    public suspend fun serviceProviderId(`value`: Output<String>) {
        this.serviceProviderId = value
    }

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("yusfjoegynuckuhv")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("rkobfafwwjaaenkl")
    public suspend fun clientSecret(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("dmvmpytxjwffoeov")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("quwoxgiryitakgki")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("lqcxwxedgppocplq")
    public suspend fun parameters(`value`: List<ConnectionSettingParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("yhcbceqkdioekvat")
    public suspend
    fun parameters(argument: List<suspend ConnectionSettingParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("jrumwvtpamishhie")
    public suspend fun parameters(
        vararg
        argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("bpfolwlohhkyqjlb")
    public suspend
    fun parameters(argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionSettingParameterArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("alymetvtcwgoqnor")
    public suspend fun parameters(vararg values: ConnectionSettingParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("mebwxfohsqcidksb")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("dtanwmetdifnsghn")
    public suspend fun scopes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("dtavlvipqyirnprs")
    public suspend fun serviceProviderDisplayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderDisplayName = mapped
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("egbaoafmmymgfdch")
    public suspend fun serviceProviderId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderId = mapped
    }

    internal fun build(): ConnectionSettingPropertiesArgs = ConnectionSettingPropertiesArgs(
        clientId = clientId,
        clientSecret = clientSecret,
        id = id,
        name = name,
        parameters = parameters,
        provisioningState = provisioningState,
        scopes = scopes,
        serviceProviderDisplayName = serviceProviderDisplayName,
        serviceProviderId = serviceProviderId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/ConnectionSettingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for a Connection Setting Item
 * @property clientId Client Id associated with the Connection Setting.
 * @property clientSecret Client Secret associated with the Connection Setting
 * @property id Id of the Connection Setting.
 * @property name Name of the Connection Setting.
 * @property parameters Service Provider Parameters associated with the Connection Setting
 * @property provisioningState Provisioning state of the resource
 * @property scopes Scopes associated with the Connection Setting
 * @property serviceProviderDisplayName Service Provider Display Name associated with the Connection Setting
 * @property serviceProviderId Service Provider Id associated with the Connection Setting
 */
public data class ConnectionSettingPropertiesArgs(
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val parameters: Output<List<ConnectionSettingParameterArgs>>? = null,
    public val provisioningState: Output<String>? = null,
    public val scopes: Output<String>? = null,
    public val serviceProviderDisplayName: Output<String>? = null,
    public val serviceProviderId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .scopes(scopes?.applyValue({ args0 -> args0 }))
            .serviceProviderDisplayName(serviceProviderDisplayName?.applyValue({ args0 -> args0 }))
            .serviceProviderId(serviceProviderId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionSettingPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionSettingPropertiesArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecret: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parameters: Output<List<ConnectionSettingParameterArgs>>? = null

    private var provisioningState: Output<String>? = null

    private var scopes: Output<String>? = null

    private var serviceProviderDisplayName: Output<String>? = null

    private var serviceProviderId: Output<String>? = null

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("vuwvnqudyaledefg")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("pbupctbainxqrgrd")
    public suspend fun clientSecret(`value`: Output<String>) {
        this.clientSecret = value
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("jsgyvgupclvoonji")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("hhbtrxldbsjyojjk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("kgnapmwpuhmcwgkn")
    public suspend fun parameters(`value`: Output<List<ConnectionSettingParameterArgs>>) {
        this.parameters = value
    }

    @JvmName("xyigiyrcdgswayfn")
    public suspend fun parameters(vararg values: Output<ConnectionSettingParameterArgs>) {
        this.parameters = Output.all(values.asList())
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("rlwlycwvirqsaigm")
    public suspend fun parameters(values: List<Output<ConnectionSettingParameterArgs>>) {
        this.parameters = Output.all(values)
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("ihtrdxwalhglvcrk")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("ywicapdttfwlwrui")
    public suspend fun scopes(`value`: Output<String>) {
        this.scopes = value
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("febjcpboaognriuh")
    public suspend fun serviceProviderDisplayName(`value`: Output<String>) {
        this.serviceProviderDisplayName = value
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("xywjerbkcdlijssm")
    public suspend fun serviceProviderId(`value`: Output<String>) {
        this.serviceProviderId = value
    }

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("qpkldmysvsgpbaup")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("qxokskodkxofejry")
    public suspend fun clientSecret(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("oiqvoxnbtnxoatup")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("rnpglungbbcndkcj")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("cfqyifvpctkmfdbs")
    public suspend fun parameters(`value`: List<ConnectionSettingParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("oasarxauxybddult")
    public suspend
    fun parameters(argument: List<suspend ConnectionSettingParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("chrdxlbwtkbqtonk")
    public suspend fun parameters(
        vararg
        argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("ajramllrgeayxetd")
    public suspend
    fun parameters(argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionSettingParameterArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("nxrsmpjligvwdeqj")
    public suspend fun parameters(vararg values: ConnectionSettingParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("cnwgxewdqqdtdmki")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("bpigjxfdbgqebrfo")
    public suspend fun scopes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("gpovsqdjnmowpbjx")
    public suspend fun serviceProviderDisplayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderDisplayName = mapped
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("jwmljprvtsfoflug")
    public suspend fun serviceProviderId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderId = mapped
    }

    internal fun build(): ConnectionSettingPropertiesArgs = ConnectionSettingPropertiesArgs(
        clientId = clientId,
        clientSecret = clientSecret,
        id = id,
        name = name,
        parameters = parameters,
        provisioningState = provisioningState,
        scopes = scopes,
        serviceProviderDisplayName = serviceProviderDisplayName,
        serviceProviderId = serviceProviderId,
    )
}
